<!DOCTYPE TS><TS version="2.1" language="de">
<context>
    <name>ChatRoomWidget</name>
    <message>
        <source>Choose a room to send messages or enter a command...</source>
        <translation>Wähle einen Raum, um Nachrichten zu senden oder Kommandos einzugeben …</translation>
    </message>
    <message>
        <source>There&apos;s nothing to send</source>
        <translation>Es gibt nichts zu senden</translation>
    </message>
    <message>
        <source>/join argument doesn&apos;t look like a room ID or alias</source>
        <translation>/join-Argument sieht nicht nach einer Raum-ID oder Alias aus</translation>
    </message>
    <message>
        <source>Sending a farewell message is not supported yet. If you intended to leave another room, switch to it and type /leave there.</source>
        <translation>Eine Abschieds-Nachricht zu senden, wird aktuell nicht unterstützt. Wenn du einen anderen Raum verlassen willst, wechsele in diesen und tippe dort /leave ein.</translation>
    </message>
    <message>
        <source>/forget must be followed by the room id/alias, even for the current room</source>
        <translation>/forget benötigt als Argument eine(n) Raum-ID/Alias, auch für den aktuellen Raum</translation>
    </message>
    <message>
        <source>%1 doesn&apos;t look like a room id or alias</source>
        <translation>%1 sieht nicht nach einer Raum-ID oder einem Raum-Alias aus</translation>
    </message>
    <message>
        <source>/invite &lt;memberId&gt;</source>
        <translation>/invite &lt;Benutzer-ID&gt;</translation>
    </message>
    <message>
        <source>/%1 &lt;userId&gt; &lt;reason&gt;</source>
        <translation>/%1 &lt;Benutzer-ID&gt; &lt;Grund&gt;</translation>
    </message>
    <message>
        <source>%1 is not a member of this room</source>
        <translation>%1 ist kein Mitglied dieses Raumes</translation>
    </message>
    <message>
        <source>/unban &lt;userId&gt;</source>
        <translation>/unban &lt;Benutzer-ID&gt;</translation>
    </message>
    <message>
        <source>/unban argument doesn&apos;t look like a user ID</source>
        <translation>/unban-Argument sieht nicht nach einer Benutzer-ID aus</translation>
    </message>
    <message>
        <source>/ignore &lt;userId&gt;</source>
        <translation>/ignore &lt;Benutzer-ID&gt;</translation>
    </message>
    <message>
        <source>/ignore argument doesn&apos;t look like a user ID</source>
        <translation>/ignore-Argument sieht nicht nach einer Benutzer-ID aus</translation>
    </message>
    <message>
        <source>Couldn&apos;t find user %1 on the server</source>
        <translation>Konnte den Benutzer %1 nicht auf dem Server finden</translation>
    </message>
    <message>
        <source>/me needs an argument</source>
        <translation>/me braucht ein Argument</translation>
    </message>
    <message>
        <source>/notice needs an argument</source>
        <translation>/notice braucht ein Argument</translation>
    </message>
    <message>
        <source>/%1 &lt;memberId&gt; &lt;message&gt;</source>
        <translation>/%1 &lt;Benutzer-ID&gt; &lt;Nachricht&gt;</translation>
    </message>
    <message>
        <source>%1 doesn&apos;t seem to have joined room %2</source>
        <translation>%1 ist dem Raum %2 anscheinend nicht beigetreten</translation>
    </message>
    <message>
        <source>%1 doesn&apos;t look like a user id or room alias</source>
        <translation>%1 sieht nicht nach einer Nutzer- oder Raum-ID aus</translation>
    </message>
    <message>
        <source>/%1 &lt;memberId&gt;</source>
        <translation>/%1 &lt;Benutzer-ID&gt;</translation>
    </message>
    <message>
        <source>Unknown /command. Use // to send this line literally</source>
        <translation>Unbekannter /Befehl. Starte mit //, um diese Zeile normal zu senden</translation>
    </message>
    <message>
        <source>Attach</source>
        <translation>Anhängen</translation>
    </message>
    <message>
        <source>Attach file</source>
        <translation>Datei anhängen</translation>
    </message>
    <message>
        <source>Add a message to the file or just push Enter</source>
        <translation>Füge der Datei eine Nachricht bei oder drücke einfach die Eingabetaste.</translation>
    </message>
    <message>
        <source>Attaching %1</source>
        <translation>Hänge %1 an</translation>
    </message>
    <message>
        <source>Attaching cancelled</source>
        <translation>Anhängen abgebrochen</translation>
    </message>
    <message>
        <source>There&apos;s no such /command outside of room.</source>
        <translation>Es gibt keinen /Befehl außerhalb von Räumen.</translation>
    </message>
    <message>
        <source>%1 doesn&apos;t look like a user id</source>
        <translation>%1 sieht nicht wie eine Benutzer-ID aus</translation>
    </message>
    <message>
        <source>%1 doesn&apos;t look like a user ID</source>
        <translation>%1 sieht nicht wie eine Benutzer-ID aus</translation>
    </message>
    <message>
        <source>You should select a room to send messages.</source>
        <translation>Wählen Sie einen Raum, um Nachrichten zu senden.</translation>
    </message>
    <message>
        <source>Send a message (over %1) or enter a command...</source>
        <translation>Sende eine Nachricht (über %1) oder gebe einen Befehl ein …</translation>
    </message>
    <message>
        <source>No completions</source>
        <translation>Keine Vervollständigungen</translation>
    </message>
    <message numerus="yes">
        <source>%Ln more completions</source>
        <translation>
            <numerusform>%Ln weitere Vervollständigung</numerusform>
            <numerusform>%Ln weitere Vervollständigungen</numerusform>
        </translation>
    </message>
    <message>
        <source>Next completion:</source>
        <translation>Nächste Vervollständigung:</translation>
    </message>
    <message>
        <source>Currently typing:</source>
        <translation>Aktuell tippen:</translation>
    </message>
    <message>
        <source>At pos %1: %2</source>
        <translation>An Position %1: %2</translation>
    </message>
    <message>
        <source>%L1 more</source>
        <translation>%L1 weitere</translation>
    </message>
    <message>
        <source>%1 is not readable or not a file</source>
        <translation>%1 ist nicht lesbar oder keine Datei</translation>
    </message>
    <message>
        <source>Attaching the pasted image</source>
        <translation>Anhängen des eingefügten Bildes</translation>
    </message>
</context>
<context>
    <name>Timeline</name>
    <message>
        <source>(no topic)</source>
        <translation>(kein Thema)</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Unbekannt</translation>
    </message>
    <message>
        <source>Unstable room version!</source>
        <translation>Instabile Raumversion!</translation>
    </message>
    <message>
        <source>(no name)</source>
        <translation>(kein Name)</translation>
    </message>
    <message numerus="yes">
        <source>%Ln byte(s)</source>
        <translation>
            <numerusform>%Ln Byte</numerusform>
            <numerusform>%Ln Bytes</numerusform>
        </translation>
    </message>
    <message>
        <source>%L1 MB</source>
        <translation>%L1 MB</translation>
    </message>
    <message>
        <source>%L1 GB</source>
        <translation>%L1 GB</translation>
    </message>
    <message>
        <source>This room has been upgraded.</source>
        <translation>Der Raum wurde aktualisiert.</translation>
    </message>
    <message>
        <source>Go to
new room</source>
        <translation>Gehe zu
neuem Raum</translation>
    </message>
    <message>
        <source>Room
settings</source>
        <translation>Raum-
Einstellungen</translation>
    </message>
    <message>
        <source>Latest events</source>
        <translation>Neueste Ereignisse</translation>
    </message>
    <message numerus="yes">
        <source>%Ln events back from now</source>
        <translation>
            <numerusform>%Ln Ereignis zurückgescrollt</numerusform>
            <numerusform>%Ln Ereignisse zurückgescrollt</numerusform>
        </translation>
    </message>
    <message>
        <source>%L1 kB</source>
        <translation>%L1 kB</translation>
    </message>
    <message numerus="yes">
        <source>%Ln events cached</source>
        <translation>
            <numerusform>%Ln Ereignis zwischengespeichert</numerusform>
            <numerusform>%Ln Ereignisse zwischengespeichert</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%Ln events requested from the server</source>
        <translation>
            <numerusform>%Ln Ereignis vom Server angefragt</numerusform>
            <numerusform>%Ln Ereignisse vom Server angefragt</numerusform>
        </translation>
    </message>
    <message>
        <source>Hide topic</source>
        <translation>Thema ausblenden</translation>
    </message>
    <message>
        <source>Show topic</source>
        <translation>Thema anzeigen</translation>
    </message>
</context>
<context>
    <name>CreateRoomDialog</name>
    <message>
        <source>Create room</source>
        <translation>Erstelle Raum</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Hinzufügen</translation>
    </message>
    <message>
        <source>Invite user(s)</source>
        <translation>Benutzer einladen</translation>
    </message>
    <message>
        <source>Creating the room, please wait</source>
        <translation>Erstelle den Raum. Bitte warten</translation>
    </message>
    <message>
        <source>Please fill the fields as desired. None are mandatory</source>
        <translation>Bitte füllen Sie die Felder wie gewünscht aus. Alle sind optional.</translation>
    </message>
</context>
<context>
    <name>Dialog</name>
    <message>
        <source>Applying changes, please wait</source>
        <translation>Änderungen werden übernommen. Bitte warten</translation>
    </message>
</context>
<context>
    <name>LoginDialog</name>
    <message>
        <source>Login</source>
        <translation>Anmelden</translation>
    </message>
    <message>
        <source>Stay logged in</source>
        <translation>Angemeldet bleiben</translation>
    </message>
    <message>
        <source>Matrix ID</source>
        <translation>Matrix-ID</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Passwort</translation>
    </message>
    <message>
        <source>Device name</source>
        <translation>Gerätename</translation>
    </message>
    <message>
        <source>Connect to server</source>
        <translation>Mit Server verbinden</translation>
    </message>
    <message>
        <source>Connecting and logging in, please wait</source>
        <translation>Am Verbinden und anmelden. Bitte warten</translation>
    </message>
    <message>
        <source>Re-login</source>
        <translation>Neu anmelden</translation>
    </message>
    <message>
        <source>Restoring access, please wait</source>
        <translation>Der Zugriff wird wiederhergestellt, warten Sie bitte</translation>
    </message>
    <message>
        <source>Resolving the homeserver...</source>
        <translation>Der Homeserver wird aufgelöst …</translation>
    </message>
    <message>
        <source>The server URL doesn&apos;t look valid</source>
        <translation>Die Server-URL sieht nicht gültig aus</translation>
    </message>
    <message>
        <source>Login with SSO</source>
        <translation>Anmeldung mit SSO</translation>
    </message>
    <message>
        <source>The homeserver is available</source>
        <translation>Der Homeserver ist verfügbar</translation>
    </message>
    <message>
        <source>Could not connect to the homeserver</source>
        <translation>Es konnte keine Verbindung zum Homeserver hergestellt werden</translation>
    </message>
    <message>
        <source>No supported login flows</source>
        <translation>Keine unterstützten Anmeldemethoden</translation>
    </message>
    <message>
        <source>Single sign-on</source>
        <translation>Single Sign-on</translation>
    </message>
    <message>
        <source>Quaternion couldn&apos;t automatically open the single sign-on URL. Please copy and paste it to the right application (usually a web browser):</source>
        <translation>Quaternion konnte die Single Sign-On-URL nicht automatisch öffnen. Bitte kopieren Sie sie und fügen Sie sie in die richtige Anwendung ein (normalerweise ein Webbrowser):</translation>
    </message>
    <message>
        <source>After authentication, the browser will follow the temporary local address setup by Quaternion to conclude the login sequence.</source>
        <translation>Nach der Authentifizierung folgt der Browser der von Quaternion eingerichteten temporären lokalen Adresse, um die Anmeldesequenz abzuschließen.</translation>
    </message>
    <message>
        <source>Getting supported login flows...</source>
        <translation>Lade unterstützte Anmeldemethoden …</translation>
    </message>
    <message>
        <source>This account is logged in already</source>
        <translation>Dieses Konto ist bereits angemeldet</translation>
    </message>
    <message>
        <source>(none)</source>
        <translation>(keiner)</translation>
    </message>
    <message>
        <source>Saved device id</source>
        <translation>Gespeicherte Geräte-ID</translation>
    </message>
    <message>
        <source>Enable E2EE (BETA)</source>
        <translation>E2EE einschalten (BETA)</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Loading...</source>
        <translation>Lädt …</translation>
    </message>
    <message>
        <source>&amp;Accounts</source>
        <translation>&amp;Konten</translation>
    </message>
    <message>
        <source>&amp;Login...</source>
        <translation>&amp;Anmelden …</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Beenden</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Oberfläche</translation>
    </message>
    <message>
        <source>&amp;Display in timeline</source>
        <translation>In &amp;Historie anzeigen</translation>
    </message>
    <message>
        <source>Normal &amp;join/leave events</source>
        <translation>Normale &amp;Zutritts-/Verlassens-Ereignisse</translation>
    </message>
    <message>
        <source>&amp;Redacted events</source>
        <translation>&amp;Gelöschte Ereignisse</translation>
    </message>
    <message>
        <source>Show redacted events in the timeline as &apos;Redacted&apos; instead of hiding them entirely</source>
        <translation>Zeige entfernte Ereignisse in der Historie als &apos;Entfernt&apos;, anstatt sie komplett zu verbergen</translation>
    </message>
    <message>
        <source>&amp;No-effect activity</source>
        <translation>&amp;Effektlose Aktivität</translation>
    </message>
    <message>
        <source>Edit tags order</source>
        <translation>Ändere Tag-Reihenfolge</translation>
    </message>
    <message>
        <source>&amp;Room</source>
        <translation>&amp;Raum</translation>
    </message>
    <message>
        <source>Change room &amp;settings...</source>
        <translation>Ändere Raum-&amp;Einstellungen …</translation>
    </message>
    <message>
        <source>Create &amp;new room...</source>
        <translation>Erstelle &amp;neuen Raum …</translation>
    </message>
    <message>
        <source>&amp;Join room...</source>
        <translation>Raum &amp;betreten …</translation>
    </message>
    <message>
        <source>&amp;Close current room</source>
        <translation>Aktuellen Raum &amp;Schließen</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Einstellungen</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Hilfe</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Über</translation>
    </message>
    <message>
        <source>&amp;Highlight only</source>
        <translation>Nur &amp;Hervorhebungen</translation>
    </message>
    <message>
        <source>Notifications are entirely suppressed</source>
        <translation>Benachrichtigungen werden komplett unterdrückt</translation>
    </message>
    <message>
        <source>&amp;Non-intrusive</source>
        <translation>&amp;Nicht-Aufdringlich</translation>
    </message>
    <message>
        <source>Show notifications but do not activate the window</source>
        <translation>Zeige Benachrichtigungen, aber Fenster nicht aktivieren</translation>
    </message>
    <message>
        <source>&amp;Full</source>
        <translation>&amp;Voll</translation>
    </message>
    <message>
        <source>Show notifications and activate the window</source>
        <translation>Zeige Benachrichtigungen und aktiviere das Fenster</translation>
    </message>
    <message>
        <source>Notifications</source>
        <translation>Benachrichtigungen</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Standard</translation>
    </message>
    <message>
        <source>The layout with author labels above blocks of messages</source>
        <translation>Autor-Kennung über Blöcken von Nachrichten</translation>
    </message>
    <message>
        <source>The layout with author labels to the left from each message</source>
        <translation>Autor-Kennung links von jeder Nachricht</translation>
    </message>
    <message>
        <source>Timeline layout</source>
        <translation>Layout der Historie</translation>
    </message>
    <message>
        <source>Load full-size images at once</source>
        <translation>Lade Bilder in voller Größe auf einmal</translation>
    </message>
    <message>
        <source>Automatically download a full-size image instead of a thumbnail</source>
        <translation>Automatisch komplettes Bild anstelle eines Vorschaubildes laden</translation>
    </message>
    <message>
        <source>Configure &amp;network proxy...</source>
        <translation>Konfiguriere &amp;Netzwerk-Proxy …</translation>
    </message>
    <message>
        <source>Logged out as %1</source>
        <translation>Als %1 abgemeldet</translation>
    </message>
    <message>
        <source>Sync failed</source>
        <translation>Synchronisieren fehlgeschlagen</translation>
    </message>
    <message>
        <source>The last sync of account %1 has failed with error: %2</source>
        <translation>Die letzte Synchronisierung von Account %1 schlug fehl mit Fehler: %2</translation>
    </message>
    <message>
        <source>The last sync has failed with error: %1</source>
        <translation>Die letzte Synchronisierung schlug fehl mit Fehler: %1</translation>
    </message>
    <message>
        <source>Clicking &apos;Retry&apos; will attempt to resume synchronisation;
Clicking &apos;Cancel&apos; will stop further synchronisation of this account until logout or Quaternion restart.</source>
        <translation>&apos;Erneut versuchen&apos; wird versuchen weiter zu Synchronisieren;
&apos;Abbrechen&apos; wird weitere Synchronisierungsversuche dieses Kontos abbrechen bis zur Abmeldung oder Quaternion-Neustart.</translation>
    </message>
    <message>
        <source>Before this server can process your information, you have to agree with its terms and conditions; please click the button below to open the web page where you can do that</source>
        <translation>Bevor dieser Server deine Informationen verarbeiten kann, musst du den Benutzungsbedingungen zustimmen. Bitte klicke auf den Button unten um eine Webseite zu öffnen, auf der du dies tun kannst</translation>
    </message>
    <message>
        <source>Open web page</source>
        <translation>Webseite öffnen</translation>
    </message>
    <message>
        <source>About Quaternion</source>
        <translation>Über Quaternion</translation>
    </message>
    <message>
        <source>Welcome to Quaternion</source>
        <translation>Willkommen bei Quaternion</translation>
    </message>
    <message>
        <source>Joined %1 as %2</source>
        <translation>%1 als %2 beigetreten</translation>
    </message>
    <message>
        <source>Couldn&apos;t connect to the server as %1; will retry within %2 seconds</source>
        <translation>Konnte nicht mit dem Server als %1 verbinden; Versuche es in %2 Sekunden erneut</translation>
    </message>
    <message>
        <source>Reconnecting...</source>
        <translation>Die Verbindung wird wiederhergestellt …</translation>
    </message>
    <message>
        <source>No SSL support</source>
        <translation>Keine SSL-Unterstützung</translation>
    </message>
    <message>
        <source>Your SSL configuration does not allow Quaternion to establish secure connections.</source>
        <translation>Deine SSL-Konfiguration erlaubt Quaternion nicht, eine sichere Verbindung herzustellen.</translation>
    </message>
    <message>
        <source>SSL error</source>
        <translation>SSL-Fehler</translation>
    </message>
    <message>
        <source>Proxy needs authentication</source>
        <translation>Proxy braucht Authentifizierung</translation>
    </message>
    <message>
        <source>Authenticate</source>
        <translation>Authentifizieren</translation>
    </message>
    <message>
        <source>User name</source>
        <translation>Benutzername</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Passwort</translation>
    </message>
    <message>
        <source>&amp;Thanks</source>
        <translation>&amp;Danke</translation>
    </message>
    <message>
        <source>Original project author: %1</source>
        <translation>Ursprünglicher Projektautor: %1</translation>
    </message>
    <message>
        <source>Web page</source>
        <translation>Webseite</translation>
    </message>
    <message>
        <source>Project leader: %1</source>
        <translation>Projektleiter: %1</translation>
    </message>
    <message>
        <source>Contributors:</source>
        <translation>Mitwirkende:</translation>
    </message>
    <message>
        <source>Quaternion contributors @ GitHub</source>
        <translation>Quaternion Mitwirkende @ GitHub</translation>
    </message>
    <message>
        <source>Quaternion translators @ Lokalise.co</source>
        <translation>Quaternion Übersetzer @ Lokalise.com</translation>
    </message>
    <message>
        <source>Made with:</source>
        <translation>Gemacht mit:</translation>
    </message>
    <message>
        <source>Show join and leave events</source>
        <translation>Zeige Betreten- und Verlassen-Ereignisse</translation>
    </message>
    <message>
        <source>Use shuttle scrollbar (requires restart)</source>
        <translation>Pendellaufleiste benutzen (erfordert Neustart)</translation>
    </message>
    <message>
        <source>Control scroll velocity instead of position with the timeline scrollbar</source>
        <translation>Der Laufleisten-Schieberegler für die Historie ändert die Laufgeschwindigkeit anstatt der Position.</translation>
    </message>
    <message>
        <source>Request URL: %1
Response:
%2</source>
        <translation>Anfrage-URL: %1
Antwort:
%2</translation>
    </message>
    <message>
        <source>Close to tray</source>
        <translation>Schließe in das Benachrichtigungsfeld.</translation>
    </message>
    <message>
        <source>Make close button [X] minimize to tray instead of closing main window</source>
        <translation>Schließen-Schaltfläche [X] minimiert in das Benachrichtigungsfeld, anstatt das Hauptfenster zu schließen.</translation>
    </message>
    <message>
        <source>Show/hide meaningless activity (join-leave pairs and redacted events between)</source>
        <translation>Ein-/ausblenden von bedeutungsloser Aktivität („betreten“–„verlassen“-Paare mit entfernten Ereignissen dazwischen)</translation>
    </message>
    <message>
        <source>Built from Git, commit SHA:</source>
        <translation>Aus Git heraus gebaut. Commit-SHA:</translation>
    </message>
    <message>
        <source>Library commit SHA:</source>
        <translation>Commit-SHA der Bibliothek:</translation>
    </message>
    <message>
        <source>Open room...</source>
        <translation>Raum öffnen …</translation>
    </message>
    <message>
        <source>Open room</source>
        <translation>Raum öffnen</translation>
    </message>
    <message>
        <source>Open a room from the room list</source>
        <translation>Einen Raum aus der Raumliste öffnen</translation>
    </message>
    <message>
        <source>Couldn&apos;t delete access token</source>
        <translation>Zugriffstoken konnte nicht gelöscht werden.</translation>
    </message>
    <message>
        <source>Open direct chat?</source>
        <translation>Direkt-Chat öffnen?</translation>
    </message>
    <message>
        <source>Open direct chat with user %1?</source>
        <translation>Direkt-Chat mit Benutzer %1 öffnen?</translation>
    </message>
    <message>
        <source>Room not found</source>
        <translation>Raum nicht gefunden</translation>
    </message>
    <message>
        <source>There&apos;s no room %1 in the room list. Check the spelling and the account.</source>
        <translation>Es gibt keinen Raum %1 in der Raumliste. Überprüfen Sie die Rechtschreibung und das Konto.</translation>
    </message>
    <message>
        <source>Confirm your account to open %1</source>
        <translation>Bestätigen Sie Ihr Konto, um %1 zu öffnen</translation>
    </message>
    <message>
        <source>Confirm account</source>
        <translation>Konto bestätigen</translation>
    </message>
    <message>
        <source>Account</source>
        <translation>Konto</translation>
    </message>
    <message>
        <source>Room ID (starting with !)
or alias (starting with #)</source>
        <translation>Raum ID (beginnend mit !) 
oder Alias (beginnend mit #)</translation>
    </message>
    <message>
        <source>Confirm account to join %1</source>
        <translation>Bestätigen Sie das Konto, um %1 beizutreten</translation>
    </message>
    <message>
        <source>Edit quote style</source>
        <translation>Zitat-Stil bearbeiten</translation>
    </message>
    <message>
        <source>Markdown (prepend each line with &gt;)</source>
        <translation>Markdown (vor jeder Zeile mit &gt;)</translation>
    </message>
    <message>
        <source>Custom (apply regex from the config file)</source>
        <translation>Benutzerdefiniert (Regex aus der Konfigurationsdatei anwenden)</translation>
    </message>
    <message>
        <source>Locale&apos;s default (%1)</source>
        <translation>Standard der Spracheinstellung (%1)</translation>
    </message>
    <message>
        <source>Example quote</source>
        <translation>Beispielzitat</translation>
    </message>
    <message>
        <source>Choose the default style of quotes</source>
        <translation>Wählen Sie den Standardstil für Zitate</translation>
    </message>
    <message>
        <source>Special thanks to %1 for all the testing effort</source>
        <translation>Besonderer Dank geht an %1 für all die Anstrengungen beim Testen</translation>
    </message>
    <message>
        <source>libQuotient contributors @ GitHub</source>
        <translation>libQuotient Mitwirkende @ GitHub</translation>
    </message>
    <message>
        <source>First sync completed for %1</source>
        <translation>Erste Synchronisierung für %1 abgeschlossen</translation>
    </message>
    <message>
        <source>Quaternion couldn&apos;t delete the access token from the keychain.</source>
        <translation>Quaternion konnte das Zugriffstoken nicht aus dem Schlüsselbund löschen.</translation>
    </message>
    <message>
        <source>No application for the link</source>
        <translation>Keine Anwendung für den Link</translation>
    </message>
    <message>
        <source>Your operating system could not find an application for the link.</source>
        <translation>Ihr Betriebssystem konnte keine Anwendung für den Link finden.</translation>
    </message>
    <message>
        <source>External link confirmation</source>
        <translation>Bestätigung für externe Links</translation>
    </message>
    <message>
        <source>An external application will be opened to visit a non-Matrix link:

%1

Is that right?</source>
        <translation>Eine externe Anwendung wird geöffnet, um einen Nicht-Matrix-Link zu besuchen: 

%1 

 Ist das richtig?</translation>
    </message>
    <message>
        <source>Do not ask again</source>
        <translation>Nicht erneut fragen</translation>
    </message>
    <message>
        <source>Malformed or empty Matrix id</source>
        <translation>Fehlerhafte oder leere Matrix-ID</translation>
    </message>
    <message>
        <source>%1 is not a correct Matrix identifier</source>
        <translation>%1 ist keine korrekte Matrix-ID</translation>
    </message>
    <message>
        <source>Please connect to a server</source>
        <translation>Bitte verbinden Sie sich mit einem Server</translation>
    </message>
    <message>
        <source>Confirm your account to open a direct chat with %1</source>
        <translation>Bestätige dein Konto, um einen direkten Chat mit %1 zu eröffnen.</translation>
    </message>
    <message>
        <source>User &amp;profiles...</source>
        <translation>&amp;Benutzerprofile …</translation>
    </message>
    <message>
        <source>Log&amp;out</source>
        <translation>A&amp;bmelden</translation>
    </message>
    <message>
        <source>Invite events</source>
        <translation>Einladungsereignisse</translation>
    </message>
    <message>
        <source>Show invite and withdrawn invitation events</source>
        <translation>Einladungs- und zurückgezogene Einladungsereignisse anzeigen</translation>
    </message>
    <message>
        <source>Ban events</source>
        <translation>Verbannungs-Ereignisse</translation>
    </message>
    <message>
        <source>Show ban and unban events</source>
        <translation>Ver- und Entbannungsereignisse anzeigen</translation>
    </message>
    <message>
        <source>Changes in display na&amp;me</source>
        <translation>Änderungen im Displaynamen</translation>
    </message>
    <message>
        <source>Show display name change</source>
        <translation>Änderungen des Anzeigenamens anzeigen</translation>
    </message>
    <message>
        <source>Avatar &amp;changes</source>
        <translation>Avataränderungen</translation>
    </message>
    <message>
        <source>Show avatar update events</source>
        <translation>Änderungen des Avatars anzeigen</translation>
    </message>
    <message>
        <source>Room alias &amp;updates</source>
        <translation>Änderungen des Raumnamens</translation>
    </message>
    <message>
        <source>Show room alias updates events</source>
        <translation>Änderungen des Raumnamens anzeigen</translation>
    </message>
    <message>
        <source>Un&amp;known event types</source>
        <translation>Unbekannte Ereignistypen</translation>
    </message>
    <message>
        <source>Show/hide unknown event types</source>
        <translation>Unbekannte Ereignistypen anzeigen/ausblenden</translation>
    </message>
    <message>
        <source>Tags can be wildcarded by * next to dot(s)
Clear the box to reset to defaults
Special tags starting with &quot;im.quotient.&quot; are: %1
User-defined tags should start with &quot;u.&quot;</source>
        <translation>In Tags kann ein * neben Punkt(en) als Platzhalter eingesetzt werden.
Entferne das Häkchen, um auf die Standardeinstellungen zurückzusetzen.
Spezielle Tags, die mit „im.quotient.“ beginnen, sind: %1
Benutzerdefinierte Etiketten sollten mit „u.“ beginnen.</translation>
    </message>
    <message>
        <source>&amp;About Quaternion</source>
        <translation>&amp;Über Quaternion</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Über &amp;Qt</translation>
    </message>
    <message>
        <source>Use Breeze style (requires restart)</source>
        <translation>Breeze-Stil verwenden (Neustart erforderlich)</translation>
    </message>
    <message>
        <source>Force use Breeze style and icon theme</source>
        <translation>Verwendung des Breeze-Stils und Symbolthemas erzwingen</translation>
    </message>
    <message>
        <source>Chat with user</source>
        <translation>Chat mit Benutzer</translation>
    </message>
    <message>
        <source>Can&apos;t open</source>
        <translation>Kann nicht geöffnet werden</translation>
    </message>
    <message>
        <source>Could not resolve id</source>
        <translation>ID konnte nicht aufgelöst werden</translation>
    </message>
    <message>
        <source>Could not find an external application to open the URI:</source>
        <translation>Es wurde keine externe Anwendung zum Öffnen des URI gefunden:</translation>
    </message>
    <message>
        <source>Could not resolve Matrix identifier</source>
        <translation>Matrix-ID konnte nicht aufgelöst werden</translation>
    </message>
    <message>
        <source>Incorrect action on a Matrix resource</source>
        <translation>Falsche Aktion für eine Matrix-Ressource</translation>
    </message>
    <message>
        <source>The URI contains an action &apos;%1&apos; that cannot be applied to Matrix resource %2</source>
        <translation>Der URI enthält eine Aktion &apos;%1&apos;, die nicht auf die Matrix-Ressource %2 angewendet werden kann</translation>
    </message>
    <message>
        <source>Room or user ID, room alias,
Matrix URI or matrix.to link</source>
        <translation>Raum- oder Benutzer-ID, Raumalias, 
Matrix URI oder matrix.to Link</translation>
    </message>
    <message>
        <source>Go to room</source>
        <translation>Gehe zu Raum</translation>
    </message>
    <message>
        <source>Join room</source>
        <translation>Raum betreten</translation>
    </message>
    <message>
        <source>Quaternion project contributors</source>
        <translation>Projektmitwirkende Quaternion</translation>
    </message>
    <message>
        <source>Felix Rohrbach</source>
        <translation>Felix Rohrbach</translation>
    </message>
    <message>
        <source>Alexey &quot;Kitsune&quot; Rusakov</source>
        <translation>Alexey &quot;Kitsune&quot; Rusakov</translation>
    </message>
    <message>
        <source>Confirm opening external links</source>
        <translation>Öffnen von externen Links bestätigen</translation>
    </message>
    <message>
        <source>Show a confirmation box before opening non-Matrix links in an external application</source>
        <translation>Zeige ein Bestätigungsfeld vor dem Öffnen von Nicht-Matrix-Links in einer externen Anwendung an</translation>
    </message>
    <message>
        <source>Account %1 is synchronised, have a good chat</source>
        <translation>Konto %1 ist synchronisiert, viel Spaß beim Chatten</translation>
    </message>
    <message numerus="yes">
        <source>All %Ln accounts synchronised, have a good chat</source>
        <translation>
            <numerusform>%Ln Konto ist synchronisiert, viel Spaß beim Chatten</numerusform>
            <numerusform>Alle %Ln Kontos sind synchronisiert, viel Spaß beim Chatten</numerusform>
        </translation>
    </message>
    <message>
        <source>&amp;Room list</source>
        <translation>&amp;Raumliste</translation>
    </message>
    <message>
        <source>&amp;Member list</source>
        <translation>&amp;Mitgliederliste</translation>
    </message>
    <message>
        <source>Dock panels</source>
        <translation>Dock-Paneele</translation>
    </message>
</context>
<context>
    <name>MessageEventModel</name>
    <message>
        <source>Today</source>
        <translation>Heute</translation>
    </message>
    <message>
        <source>Yesterday</source>
        <translation>Gestern</translation>
    </message>
    <message>
        <source>The day before yesterday</source>
        <translation>Vorgestern</translation>
    </message>
    <message>
        <source>Redacted</source>
        <translation>Entfernt</translation>
    </message>
    <message>
        <source>Redacted: %1</source>
        <translation>Entfernt: %1</translation>
    </message>
    <message>
        <source>a file</source>
        <translation>eine Datei</translation>
    </message>
    <message>
        <source>invited %1 to the room</source>
        <translation>lud %1 in den Raum ein</translation>
    </message>
    <message>
        <source>joined the room</source>
        <translation>trat dem Raum bei</translation>
    </message>
    <message>
        <source>cleared the display name</source>
        <translation>löschte den Anzeigenamen</translation>
    </message>
    <message>
        <source>changed the display name to %1</source>
        <translation>änderte den Anzeigenamen zu %1</translation>
    </message>
    <message>
        <source>cleared the avatar</source>
        <translation>entfernte das Profilbild</translation>
    </message>
    <message>
        <source>updated the avatar</source>
        <translation>änderte das Profilbild</translation>
    </message>
    <message>
        <source>unbanned %1</source>
        <translation>hob Verbannung von %1 auf</translation>
    </message>
    <message>
        <source>self-unbanned</source>
        <translation>hob Verbannung von sich selbst auf</translation>
    </message>
    <message>
        <source>left the room</source>
        <translation>verließ den Raum</translation>
    </message>
    <message>
        <source>self-banned from the room</source>
        <translation>verbannte sich selbst aus dem Raum</translation>
    </message>
    <message>
        <source>knocked</source>
        <translation>klopfte an</translation>
    </message>
    <message>
        <source>made something unknown</source>
        <translation>tat etwas Unbekanntes</translation>
    </message>
    <message>
        <source>cleared the room main alias</source>
        <translation>entfernte den Haupt-Alias des Raumes</translation>
    </message>
    <message>
        <source>set the room main alias to: %1</source>
        <translation>setzte den Haupt-Alias des Raumes auf: %1</translation>
    </message>
    <message>
        <source>cleared the room name</source>
        <translation>entfernte den Raumnamen</translation>
    </message>
    <message>
        <source>set the room name to: %1</source>
        <translation>setzte den Raumnamen auf: %1</translation>
    </message>
    <message>
        <source>cleared the topic</source>
        <translation>entfernte das Thema</translation>
    </message>
    <message>
        <source>set the topic to: %1</source>
        <translation>setzte das Thema auf: %1</translation>
    </message>
    <message>
        <source>changed the room avatar</source>
        <translation>änderte das Raumbild</translation>
    </message>
    <message>
        <source>activated End-to-End Encryption</source>
        <translation>aktivierte Ende-zu-Ende-Verschlüsselung</translation>
    </message>
    <message>
        <source>withdrew %1&apos;s invitation</source>
        <translation>zog %1s Einladung zurück</translation>
    </message>
    <message>
        <source>rejected the invitation</source>
        <translation>lehnte die Einladung ab</translation>
    </message>
    <message>
        <source>updated the database</source>
        <translation>aktualisierte die Datenbank.</translation>
    </message>
    <message>
        <source>updated %1 state</source>
        <translation>aktualisierte %1-Status</translation>
    </message>
    <message>
        <source>updated %1 state for %2</source>
        <translation>aktualisierte %1-Status für %2.</translation>
    </message>
    <message>
        <source>Unknown event</source>
        <translation>Unbekanntes Ereignis</translation>
    </message>
    <message>
        <source>upgraded the room to version %1</source>
        <translation>aktualisierte den Raum auf Version %1</translation>
    </message>
    <message>
        <source>created the room, version %1</source>
        <translation>erstellte den Raum, Version %1</translation>
    </message>
    <message>
        <source>banned %1 from the room: %2</source>
        <translation>verbannte %1 aus dem Raum: %2</translation>
    </message>
    <message>
        <source>kicked %1 from the room: %2</source>
        <translation>hat %1 aus dem Raum entfernt: %2</translation>
    </message>
    <message>
        <source>upgraded the room: %1</source>
        <translation>aktualisierte den Raum: %1</translation>
    </message>
    <message>
        <source> and </source>
        <translation> und </translation>
    </message>
    <message numerus="yes">
        <source>%Ln more member(s)</source>
        <translation>
            <numerusform>%Ln weiteres Mitglied</numerusform>
            <numerusform>%Ln weitere Mitglieder</numerusform>
        </translation>
    </message>
    <message>
        <source>(repeated)</source>
        <translation>(wiederholt)</translation>
    </message>
    <message>
        <source>kicked %1 from the room</source>
        <translation>hat %1 aus dem Raum entfernt</translation>
    </message>
</context>
<context>
    <name>NetworkConfigDialog</name>
    <message>
        <source>Network proxy settings</source>
        <translation>Netzwerk Proxy-Einstellungen</translation>
    </message>
    <message>
        <source>&amp;Override system defaults</source>
        <translation>&amp;System-Einstellungen überschreiben</translation>
    </message>
    <message>
        <source>&amp;No proxy</source>
        <translation>&amp;Kein Proxy</translation>
    </message>
    <message>
        <source>&amp;HTTP(S) proxy</source>
        <translation>&amp;HTTP(S) Proxy</translation>
    </message>
    <message>
        <source>&amp;SOCKS5 proxy</source>
        <translation>&amp;SOCKS5 Proxy</translation>
    </message>
    <message>
        <source>Host</source>
        <translation>Host</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>User name</source>
        <translation>Benutzername</translation>
    </message>
</context>
<context>
    <name>RoomDialogBase</name>
    <message>
        <source>Publish room in room directory</source>
        <translation>Raum im Raumverzeichnis veröffentlichen</translation>
    </message>
    <message>
        <source>Allow guest accounts to join the room</source>
        <translation>Erlaube Gastkonten diesen Raum zu betreten</translation>
    </message>
    <message>
        <source>Account</source>
        <translation>Konto</translation>
    </message>
    <message>
        <source>Room name</source>
        <translation>Raumname</translation>
    </message>
    <message>
        <source>Primary alias</source>
        <translation>Primärer Alias</translation>
    </message>
    <message>
        <source>Topic</source>
        <translation>Thema</translation>
    </message>
    <message>
        <source>About room versions</source>
        <translation>Über Raumversionen</translation>
    </message>
    <message>
        <source>(loading)</source>
        <translation>(Laden)</translation>
    </message>
    <message>
        <source>default</source>
        <translation>Standard</translation>
    </message>
    <message>
        <source>stable</source>
        <translation>stabil</translation>
    </message>
    <message>
        <source>Room version</source>
        <translation>Raumversion</translation>
    </message>
    <message>
        <source>Continue with unstable version?</source>
        <translation>Mit instabiler Version fortfahren?</translation>
    </message>
    <message>
        <source>You are using an UNSTABLE room version (%1). The server may stop supporting it at any moment. Do you still want to use this version?</source>
        <translation>Sie verwenden eine INSTABILE Raumversion (%1). Der Server kann die Unterstützung jederzeit einstellen. Möchten Sie diese Version noch verwenden?</translation>
    </message>
</context>
<context>
    <name>RoomListDock</name>
    <message>
        <source>Mark room as read</source>
        <translation>Raum als gelesen markieren</translation>
    </message>
    <message>
        <source>Add tags...</source>
        <translation>Tags hinzufügen …</translation>
    </message>
    <message>
        <source>Join room</source>
        <translation>Raum betreten</translation>
    </message>
    <message>
        <source>Forget room</source>
        <translation>Raum vergessen</translation>
    </message>
    <message>
        <source>Remove tag</source>
        <translation>Tag entfernen</translation>
    </message>
    <message>
        <source>Reject invitation</source>
        <translation>Einladung ablehnen</translation>
    </message>
    <message>
        <source>Leave room</source>
        <translation>Raum verlassen</translation>
    </message>
    <message>
        <source>Enter new tags for the room</source>
        <translation>Neue Tags für den Raum eingeben</translation>
    </message>
    <message>
        <source>Enter tags to add to this room, one tag per line</source>
        <translation>Gebe Tags für den Raum ein, ein Tag pro Zeile</translation>
    </message>
    <message>
        <source>Change room &amp;settings...</source>
        <translation>Ändere Raum-&amp;Einstellungen …</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Hinzufügen</translation>
    </message>
    <message>
        <source>Copy room link to clipboard</source>
        <translation>Raumlink in die Zwischenablage kopieren</translation>
    </message>
    <message>
        <source>Rooms (%L1)</source>
        <translation>Räume (%L1)</translation>
    </message>
</context>
<context>
    <name>RoomListModel</name>
    <message>
        <source>Invited</source>
        <translation>Eingeladen</translation>
    </message>
    <message>
        <source>Low priority</source>
        <translation>Niedrige Priorität</translation>
    </message>
    <message>
        <source>People</source>
        <translation>Personen</translation>
    </message>
    <message>
        <source>Ungrouped rooms</source>
        <translation>Nicht-gruppierte Räume</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Verlassen</translation>
    </message>
    <message numerus="yes">
        <source>%1 (%Ln room(s))</source>
        <translation>
            <numerusform>%1 (%Ln Raum)</numerusform>
            <numerusform>%1 (%Ln Räume)</numerusform>
        </translation>
    </message>
    <message>
        <source>%1 (as %2)</source>
        <translation>%1 (als %2)</translation>
    </message>
    <message>
        <source>Main alias: %1</source>
        <translation>Hauptalias: %1</translation>
    </message>
    <message>
        <source>Direct chat with %1</source>
        <translation>Direkt-Chat mit %1</translation>
    </message>
    <message>
        <source>The room enforces encryption</source>
        <translation>Der Raum erzwingt Verschlüsselung</translation>
    </message>
    <message>
        <source>Favourites</source>
        <translation>Favoriten</translation>
    </message>
    <message>
        <source>This room&apos;s version is unstable!</source>
        <translation>Die Version dieses Raumes ist instabil!</translation>
    </message>
    <message>
        <source>Consider upgrading to a stable version (use room settings for that)</source>
        <translation>Erwägen Sie ein Upgrade auf eine stabile Version (verwenden Sie dafür die Raumeinstellungen).</translation>
    </message>
    <message>
        <source>Server notices</source>
        <translation>Serverbenachrichtigungen</translation>
    </message>
    <message>
        <source>Joined: %L1</source>
        <translation>Beigetreten: %L1</translation>
    </message>
    <message>
        <source>Invited: %L1</source>
        <translation>Eingeladen: %L1</translation>
    </message>
    <message>
        <source>(maybe more)</source>
        <translation>(vielleicht mehr)</translation>
    </message>
    <message>
        <source>Events after fully read marker: %L1</source>
        <translation>Ereignisse nach vollständig gelesenem Marker: %L1</translation>
    </message>
    <message>
        <source>Room id: %1</source>
        <translation>Raum-ID: %1</translation>
    </message>
    <message>
        <source>You joined this room as %1</source>
        <translation>Sie sind diesem Raum als %1 beigetreten</translation>
    </message>
    <message>
        <source>You were invited into this room as %1</source>
        <translation>Sie wurden als %1 in diesen Raum eingeladen</translation>
    </message>
    <message>
        <source>You left this room as %1</source>
        <translation>Sie haben diesen Raum als %1 verlassen</translation>
    </message>
</context>
<context>
    <name>RoomSettingsDialog</name>
    <message>
        <source>Room settings: %1</source>
        <translation>Raum-Einstellungen: %1</translation>
    </message>
    <message>
        <source>Update room</source>
        <translation>Raum aktualisieren</translation>
    </message>
    <message>
        <source>Tags</source>
        <translation>Tags</translation>
    </message>
    <message>
        <source>This version is unstable! Consider upgrading.</source>
        <translation>Diese Version ist instabil! Erwägen Sie ein Upgrade.</translation>
    </message>
    <message>
        <source>Upgrade</source>
        <translation>Aktualisierung</translation>
    </message>
    <message>
        <source>Choose new room version</source>
        <translation>Neue Raumversion auswählen</translation>
    </message>
    <message>
        <source>You are about to upgrade %1.
This operation cannot be reverted.</source>
        <translation>Sie sind dabei, %1 zu aktualisieren. 
Dieser Vorgang kann nicht rückgängig gemacht werden.</translation>
    </message>
    <message>
        <source>Creating the new room version, please wait</source>
        <translation>Die neue Raumversion wird erstellt, bitte warten</translation>
    </message>
    <message>
        <source>Room identifier</source>
        <translation>Raum-ID</translation>
    </message>
</context>
<context>
    <name>UserListDock</name>
    <message>
        <source>Users</source>
        <translation>Benutzer</translation>
    </message>
    <message>
        <source>Open direct chat</source>
        <translation>Öffne Direkt-Chat</translation>
    </message>
    <message>
        <source>Mention user</source>
        <translation>Benutzer erwähnen</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Suchen</translation>
    </message>
    <message>
        <source>Ignore user</source>
        <translation>Benutzer ignorieren</translation>
    </message>
    <message>
        <source>Kick user</source>
        <translation>Benutzer herauswerfen</translation>
    </message>
    <message>
        <source>Ban user</source>
        <translation>Benutzer verbannen</translation>
    </message>
    <message>
        <source>Kick %1</source>
        <translation>%1 herauswerfen</translation>
    </message>
    <message>
        <source>Reason</source>
        <translation>Grund</translation>
    </message>
    <message>
        <source>Ban %1</source>
        <translation>%1 verbannen</translation>
    </message>
    <message>
        <source>(%L1 out of %L2)</source>
        <translation>(%L1 von %L2)</translation>
    </message>
</context>
<context>
    <name>FileContent</name>
    <message>
        <source>Size: %1, declared type: %2</source>
        <translation>Größe: %1, angegebener Typ: %2</translation>
    </message>
    <message>
        <source>Open after downloading</source>
        <translation>Nach dem Herunterladen öffnen</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Save as...</source>
        <translation>Speichern unter …</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Öffnen</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Ordner öffnen</translation>
    </message>
    <message>
        <source>uploaded from %1</source>
        <translation>hochgeladen von %1</translation>
    </message>
    <message>
        <source>being uploaded from %1</source>
        <translation>lädt hoch von %1</translation>
    </message>
    <message>
        <source>downloaded to %1</source>
        <translation>nach %1 heruntergeladen</translation>
    </message>
</context>
<context>
    <name>TimelineItem</name>
    <message>
        <source>Resend</source>
        <translation>Erneut senden</translation>
    </message>
    <message>
        <source>Discard</source>
        <translation>Verwerfen</translation>
    </message>
    <message>
        <source>edited</source>
        <translation>bearbeitet</translation>
    </message>
    <message>
        <source>Go to
older room</source>
        <translation>Gehe zu
älterem Raum</translation>
    </message>
    <message>
        <source>Go to
new room</source>
        <translation>Gehe zu
neuem Raum</translation>
    </message>
    <message>
        <source>Reaction &apos;%1&apos; from %2</source>
        <translation>Reaktion &apos;%1&apos; von %2</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Quaternion - an IM client for the Matrix protocol</source>
        <translation>Quaternion – ein Chat-Client für das Matrix-Protokoll</translation>
    </message>
    <message>
        <source>Override locale</source>
        <translation>Sprache überschreiben</translation>
    </message>
    <message>
        <source>locale</source>
        <translation>Sprache</translation>
    </message>
    <message>
        <source>Hide main window on startup</source>
        <translation>Starte mit verstecktem Hauptfenster</translation>
    </message>
</context>
<context>
    <name>SystemTrayIcon</name>
    <message>
        <source>Highlight in %1</source>
        <translation>Hervorhebung in %1</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation>Ausblenden</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Beenden</translation>
    </message>
    <message>
        <source>Show</source>
        <translation>Anzeigen</translation>
    </message>
    <message numerus="yes">
        <source>%Ln highlight(s)</source>
        <translation>
            <numerusform>%Ln Hervorhebung</numerusform>
            <numerusform>%Ln Hervorhebungen</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>ThumbnailResponse</name>
    <message>
        <source>Image request has been cancelled</source>
        <translation>Bildanfrage wurde abgebrochen</translation>
    </message>
</context>
<context>
    <name>TimelineWidget</name>
    <message>
        <source>Referenced message not found</source>
        <translation>Referenzierte Nachricht nicht gefunden</translation>
    </message>
    <message>
        <source>Copy permalink to clipboard</source>
        <translation>Permalink in die Zwischenablage kopieren</translation>
    </message>
    <message>
        <source>Show details</source>
        <translation>Zeige Details</translation>
    </message>
    <message>
        <source>Open Folder</source>
        <translation>Ordner öffnen</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Herunterladen</translation>
    </message>
    <message>
        <source>Save file as...</source>
        <translation>Datei speichern unter …</translation>
    </message>
    <message>
        <source>Copy selected text to clipboard</source>
        <translation>Markierten Text in die Zwischenablage kopieren</translation>
    </message>
    <message>
        <source>Copy image to clipboard</source>
        <translation>Bild in die Zwischenablage kopieren</translation>
    </message>
    <message>
        <source>Save file as</source>
        <translation>Datei speichern unter</translation>
    </message>
    <message>
        <source>Redact</source>
        <translation>Entfernen</translation>
    </message>
    <message>
        <source>Copy link to clipboard</source>
        <translation>Link in Zwischenablage kopieren</translation>
    </message>
    <message>
        <source>Quote</source>
        <translation>Zitieren</translation>
    </message>
    <message>
        <source>Open externally</source>
        <translation>Extern öffnen</translation>
    </message>
</context>
<context>
    <name>ProfileDialog</name>
    <message>
        <source>This is the current device</source>
        <translation>Dies ist das aktuelle Gerät</translation>
    </message>
    <message>
        <source>Device display name</source>
        <translation>Anzeigename des Geräts</translation>
    </message>
    <message>
        <source>Device ID</source>
        <translation>Geräte-ID</translation>
    </message>
    <message>
        <source>Last time seen</source>
        <translation>Zuletzt gesehen</translation>
    </message>
    <message>
        <source>Last IP address</source>
        <translation>Letzte IP-Adresse</translation>
    </message>
    <message>
        <source>User profiles</source>
        <translation>Benutzerprofile</translation>
    </message>
    <message>
        <source>Account</source>
        <translation>Konto</translation>
    </message>
    <message>
        <source>Display Name</source>
        <translation>Anzeigename</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>In die Zwischenablage kopieren</translation>
    </message>
    <message>
        <source>Access token</source>
        <translation>Zugriffstoken</translation>
    </message>
    <message>
        <source>Apply and close</source>
        <translation>Übernehmen und schließen</translation>
    </message>
    <message>
        <source>Loading other devices...</source>
        <translation>Lade andere Geräte …</translation>
    </message>
    <message>
        <source>No avatar</source>
        <translation>Kein Avatar</translation>
    </message>
    <message>
        <source>Set avatar</source>
        <translation>Avatar einstellen</translation>
    </message>
</context>
<context>
    <name>ChatEdit</name>
    <message>
        <source>Reset formatting</source>
        <translation>Formatierung zurücksetzen</translation>
    </message>
    <message>
        <source>Reset the current character formatting to the default</source>
        <translation>Zurücksetzen der aktuellen Zeichenformatierung auf die Standardeinstellung</translation>
    </message>
    <message>
        <source>Could not insert HTML - it&apos;s either invalid or unsupported</source>
        <translation>HTML konnte nicht eingefügt werden – es ist entweder ungültig oder wird nicht unterstützt</translation>
    </message>
    <message>
        <source>Paste as rich text</source>
        <translation>Als Rich-Text einfügen</translation>
    </message>
    <message>
        <source>Paste as plain text</source>
        <translation>Als Klartext einfügen</translation>
    </message>
</context>
<context>
    <name>DockModeMenu</name>
    <message>
        <source>&amp;Off</source>
        <translation>&amp;Aus</translation>
    </message>
    <message>
        <source>&amp;Docked</source>
        <translation>Ange&amp;dockt</translation>
    </message>
    <message>
        <source>&amp;Floating</source>
        <translation>&amp;Schwebend</translation>
    </message>
    <message>
        <source>Completely hide this list</source>
        <translation>Diese Liste vollständig ausblenden</translation>
    </message>
    <message>
        <source>The list is shown within the main window</source>
        <translation>Die Liste wird im Hauptfenster angezeigt</translation>
    </message>
    <message>
        <source>The list is shown separately from the main window</source>
        <translation>Die Liste wird getrennt vom Hauptfenster angezeigt</translation>
    </message>
</context>
<context>
    <name>AbstractThumbnailResponse</name>
    <message>
        <source>No connection to perform image request</source>
        <translation>Keine Verbindung zum Durchführen einer Bildanforderung</translation>
    </message>
    <message>
        <source>Image request is pending</source>
        <translation>Bildanforderung ist ausstehend</translation>
    </message>
</context>
</TS>
